==> kubernetes-model-batch-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyOnExitCodesRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodFailurePolicyOnExitCodesRequirementBuilder extends PodFailurePolicyOnExitCodesRequirementFluent<PodFailurePolicyOnExitCodesRequirementBuilder> implements VisitableBuilder<PodFailurePolicyOnExitCodesRequirement,PodFailurePolicyOnExitCodesRequirementBuilder>{
  public PodFailurePolicyOnExitCodesRequirementBuilder() {
    this(false);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(Boolean validationEnabled) {
    this(new PodFailurePolicyOnExitCodesRequirement(), validationEnabled);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent) {
    this(fluent, false);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodFailurePolicyOnExitCodesRequirement(), validationEnabled);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent,PodFailurePolicyOnExitCodesRequirement instance) {
    this(fluent, instance, false);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent,PodFailurePolicyOnExitCodesRequirement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodFailurePolicyOnExitCodesRequirement());

    if (instance != null) {
      fluent.withContainerName(instance.getContainerName());
      fluent.withOperator(instance.getOperator());
      fluent.withValues(instance.getValues());
      fluent.withContainerName(instance.getContainerName());
      fluent.withOperator(instance.getOperator());
      fluent.withValues(instance.getValues());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirement instance) {
    this(instance,false);
  }
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirement instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodFailurePolicyOnExitCodesRequirement());

    if (instance != null) {
      this.withContainerName(instance.getContainerName());
      this.withOperator(instance.getOperator());
      this.withValues(instance.getValues());
      this.withContainerName(instance.getContainerName());
      this.withOperator(instance.getOperator());
      this.withValues(instance.getValues());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodFailurePolicyOnExitCodesRequirementFluent<?> fluent;
  Boolean validationEnabled;
  public PodFailurePolicyOnExitCodesRequirement build() {
    PodFailurePolicyOnExitCodesRequirement buildable = new PodFailurePolicyOnExitCodesRequirement(fluent.getContainerName(),fluent.getOperator(),fluent.getValues());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-batch-7.5.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyOnExitCodesRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
public class PodFailurePolicyOnExitCodesRequirementBuilder extends PodFailurePolicyOnExitCodesRequirementFluent<PodFailurePolicyOnExitCodesRequirementBuilder> implements VisitableBuilder<PodFailurePolicyOnExitCodesRequirement,PodFailurePolicyOnExitCodesRequirementBuilder>{

  PodFailurePolicyOnExitCodesRequirementFluent<?> fluent;

  public PodFailurePolicyOnExitCodesRequirementBuilder() {
    this(new PodFailurePolicyOnExitCodesRequirement());
  }
  
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent) {
    this(fluent, new PodFailurePolicyOnExitCodesRequirement());
  }
  
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirement instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  
  public PodFailurePolicyOnExitCodesRequirementBuilder(PodFailurePolicyOnExitCodesRequirementFluent<?> fluent,PodFailurePolicyOnExitCodesRequirement instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }

  public PodFailurePolicyOnExitCodesRequirement build() {
    PodFailurePolicyOnExitCodesRequirement buildable = new PodFailurePolicyOnExitCodesRequirement(fluent.getContainerName(), fluent.getOperator(), fluent.getValues());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
